@@ -42,10 +42,11 @@ Audex::Audex(QWidget* parent, ProfileModel *profile_model, CDDAModel *cdda_model
   }
 
   cdda_extract_thread = new CDDAExtractThread(this, cdda_model->device());
-  if (!encoder_wrapper) {
+  if (!cdda_extract_thread) {
     kDebug() << "PANIC ERROR. Could not load object CDDAExtractThread. Low mem?";
     return;
   }
+  cdda_extract_thread->setSampleOffset(Preferences::sampleOffset());
 
   jobs = new AudexJobs();
   connect(jobs, SIGNAL(newJobAvailable()), this, SLOT(start_encode()));
@@ -183,7 +184,7 @@ void Audex::start_extract() {
         artist,
         title);
 
-      QString sourceFilename = tmp_path+QString("%1").arg(cdda_model->discid())+".wav";
+      QString sourceFilename = tmp_path+QString("%1").arg(DiscIDCalculator::FreeDBId(cdda_model->discSignature()))+".wav";
       ex_track_source_filename = sourceFilename;
       wave_file_writer->open(sourceFilename);
 
@@ -260,7 +261,7 @@ void Audex::start_extract() {
           tartist,
           ttitle);
 
-        QString sourceFilename = tmp_path+QString("%1").arg(cdda_model->discid())+"."+QString("%1").arg(ex_track_index)+".wav";
+        QString sourceFilename = tmp_path+QString("%1").arg(DiscIDCalculator::FreeDBId(cdda_model->discSignature()))+"."+QString("%1").arg(ex_track_index)+".wav";
         ex_track_source_filename = sourceFilename;
         wave_file_writer->open(sourceFilename);
 
@@ -487,18 +488,6 @@ void Audex::write_to_wave(const QByteArray& data) {
   wave_file_writer->write(data);
 }
 
-void Audex::start_ftp_transfer(const QString& filename) {
-  emit ftpUploadStart(filename);
-}
-
-void Audex::progress_ftp_transfer(const int percent, const int overall) {
-  emit ftpUploadProgress(percent, overall);
-}
-
-void Audex::finished_ftp_transfer(const QString& filename) {
- emit ftpUploadFinished(filename);
-}
-
 void Audex::slot_error(const QString& description, const QString& solution) {
   emit error(description, solution);
   request_finish(FALSE);
@@ -815,7 +804,7 @@ void Audex::execute_finish() {
         QStringList text = profile_model->data(profile_model->index(profile_model->currentProfileRow(), PROFILE_MODEL_COLUMN_INF_TEXT_INDEX)).toStringList();
         patternparser.parseInfoText(text, cdda_model->artist(), cdda_model->title(),
           QString("%1").arg(cdda_model->year()), cdda_model->genre(),
-          cdda_model->discid(), p_size_of_all_files(target_filename_list), cdda_model->lengthOfAudioTracksInSelection(), cdda_model->numOfAudioTracksInSelection());
+          DiscIDCalculator::FreeDBId(cdda_model->discSignature()), p_size_of_all_files(target_filename_list), cdda_model->lengthOfAudioTracksInSelection(), cdda_model->numOfAudioTracksInSelection());
         out << text.join("\n");
         file.close();
         emit info(i18n("Info file \"%1\" successfully created.", QFileInfo(filename).fileName()));
