@@ -55,11 +55,13 @@
 
 #include "preferences.h"
 #include "widgets/generalsettingswidget.h"
+#include "widgets/devicewidget.h"
 #include "widgets/profilewidget.h"
 #include "widgets/remoteserversettingswidget.h"
 #include "widgets/cddaheaderwidget.h"
 
 #include "dialogs/extractingprogressdialog.h"
+#include "dialogs/errordialog.h"
 
 #include "utils/encoderassistant.h"
 
