@@ -20,6 +20,8 @@
 
 CDDAModel::CDDAModel(QObject *parent, const QString& device) : QAbstractTableModel(parent) {
 
+  cddb_transaction_pending = FALSE;
+
   compact_disc = new KCompactDisc();
   if (!compact_disc) {
     kDebug() << "Unable to create KCompactDisc object. Low mem?";
@@ -62,7 +64,7 @@ CDDAModel::~CDDAModel() {
 
 void CDDAModel::setDevice(const QString& device) {
   this->_device = device;
-  compact_disc->setDevice(device, 50, FALSE);
+  if (!device.isEmpty()) compact_disc->setDevice(device, 50, FALSE);
 }
 
 int CDDAModel::rowCount(const QModelIndex &parent) const {
@@ -231,10 +233,6 @@ Qt::ItemFlags CDDAModel::flags(const QModelIndex &index) const {
 
 }
 
-unsigned int CDDAModel::discid() const {
-  return compact_disc->discId();
-}
-
 void CDDAModel::setArtist(const QString& a) {
   if (compact_disc->isNoDisc() || compact_disc->discId()==0) return;
   if (a != cd_info.get(KCDDB::Artist).toString()) {
@@ -616,7 +614,7 @@ int CDDAModel::lengthOfTrack(int n) const {
   return compact_disc->trackLength(n);
 }
 
-const QList<unsigned> CDDAModel::discSignature() const {
+const QList<quint32> CDDAModel::discSignature() const {
   return compact_disc->discSignature();
 }
 
@@ -737,6 +735,12 @@ void CDDAModel::lookupCDDB() {
 
   kDebug() << "lookupCDDB called";
 
+  if (cddb_transaction_pending) {
+    kDebug() << "CDDB transaction already in progress.";
+    return;
+  }
+  cddb_transaction_pending = TRUE;
+
   emit cddbLookupStarted();
 
   cddb->config().reparse();
@@ -751,6 +755,14 @@ bool CDDAModel::submitCDDB() {
 
   kDebug() << "submitCDDB called";
 
+  if (cddb_transaction_pending) {
+    kDebug() << "CDDB transaction already in progress.";
+    error = Error(i18n("CDDB transaction already in progress."), i18n("A CDDB transaction is already in progress. Please wait until it has finished and try again."), Error::ERROR, this);
+    return FALSE;
+  }
+
+  cddb_transaction_pending = TRUE;
+
   cddb->config().reparse();
   cddb->setBlockingMode(TRUE);
   if (category().isEmpty()) {
@@ -778,6 +790,8 @@ bool CDDAModel::submitCDDB() {
 
   confirm();
 
+  cddb_transaction_pending = FALSE;
+
   emit cddbDataSubmited(TRUE);
 
   return TRUE;
@@ -956,6 +970,8 @@ void CDDAModel::lookup_cddb_done(KCDDB::Result result) {
   }
   reset();
 
+  cddb_transaction_pending = FALSE;
+
   emit cddbLookupDone(TRUE);
 
   emit discInfoChanged(disc_info);
