@@ -138,6 +138,32 @@ int CDDAParanoia::lastSectorOfDisc() {
   return -1;
 }
 
+void CDDAParanoia::sampleOffset(const int offset) {
+
+  int sample_offset = offset;
+
+  // Hack from cdda paranoia
+  if (paranoia_drive) {
+
+    mutex.lock();
+
+    int toc_offset = 0;
+    toc_offset += sample_offset / 588;
+    sample_offset %= 588;
+    if (sample_offset < 0) {
+      sample_offset += 588;
+      toc_offset--;
+    }
+
+    for (int i = 0; i < paranoia_drive->tracks+1; ++i)
+      paranoia_drive->disc_toc[i].dwStartSector += toc_offset;
+
+    mutex.unlock();
+
+  }
+
+}
+
 int CDDAParanoia::numOfTracks() {
   if (paranoia_drive) return (paranoia_drive->tracks<0)?0:paranoia_drive->tracks;
   return 0;
@@ -242,12 +268,15 @@ bool CDDAParanoia::isAudioTrack(int n) {
   return TRUE;
 }
 
-quint32 CDDAParanoia::discid() {
-  quint32 cksum = 0;
-  for (int i = 1; i <= numOfTracks(); i++) {
-    cksum += checksum((frameOffsetOfTrack(i)+150) / 75);
-  }
-  return ((cksum % 0xff) << 24 | length() << 8 | numOfTracks());
+QList<quint32> CDDAParanoia::discSignature(const qint32 pregap) {
+
+  QList<quint32> result;
+
+  for (int i = 1; i <= numOfTracks()+1; ++i)
+    result.append(frameOffsetOfTrack(i)+pregap);
+
+  return result;
+
 }
 
 void CDDAParanoia::reset() {
