@@ -35,16 +35,6 @@ generalSettingsWidget::generalSettingsWidget(QWidget* parent) : generalSettingsW
   urlreq_basePath->setMode(KFile::Directory|KFile::LocalOnly);
   urlreq_basePath->lineEdit()->setObjectName("kcfg_basePath");
 
-  QStringList devices = KCompactDisc::cdromDeviceNames();
-  kcfg_cdDevice->clear();
-
-  if (devices.isEmpty()) {
-    kcfg_cdDevice->addItem(i18n("None detected"));
-  } else {
-    foreach (const QString &dev, devices) {
-      kcfg_cdDevice->addItem(dev + " (" + KCompactDisc::cdromDeviceUrl(dev).path() + ")");
-    }
-  }
 }
 
 generalSettingsWidget::~generalSettingsWidget() {
